@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::deps_all;
 
 our $DATE = '2016-12-27'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -22,14 +22,16 @@ distribution name, so you can view all dependencies in the `dep` table.
 
 _
     args => {
-        %App::lcpan::deps_phase_args,
-        %App::lcpan::deps_rel_args,
+        %App::lcpan::rdeps_phase_args,
+        %App::lcpan::rdeps_rel_args,
         module => {
-            schema => 'perl::modname*',
+            summary => 'Module name (can contain % for SQL LIKE query)',
+            schema => 'str*',
             tags => ['category:filtering'],
         },
         dist => {
-            schema => 'perl::distname*',
+            summary => 'Distribution name (can contain % for SQL LIKE query)',
+            schema => 'str*',
             tags => ['category:filtering'],
         },
         module_author => {
@@ -54,7 +56,11 @@ sub handle_cmd {
     my @binds  = ();
 
     if ($args{module}) {
-        push @wheres, "m.name=?";
+        if ($args{module} =~ /%/) {
+            push @wheres, "m.name LIKE ?";
+        } else {
+            push @wheres, "m.name=?";
+        }
         push @binds, $args{module};
     }
     if ($args{module_author}) {
@@ -62,7 +68,11 @@ sub handle_cmd {
         push @binds, uc $args{module_author};
     }
     if ($args{dist}) {
-        push @wheres, "dist=?";
+        if ($args{dist} =~ /%/) {
+            push @wheres, "d.name LIKE ?";
+        } else {
+            push @wheres, "d.name=?";
+        }
         push @binds, $args{dist};
     }
     if ($args{dist_author}) {
@@ -117,7 +127,7 @@ App::lcpan::Cmd::deps_all - List all dependencies
 
 =head1 VERSION
 
-This document describes version 0.001 of App::lcpan::Cmd::deps_all (from Perl distribution App-lcpan-CmdBundle-deps), released on 2016-12-27.
+This document describes version 0.002 of App::lcpan::Cmd::deps_all (from Perl distribution App-lcpan-CmdBundle-deps), released on 2016-12-27.
 
 =head1 FUNCTIONS
 
@@ -135,17 +145,21 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<dist> => I<perl::distname>
+=item * B<dist> => I<str>
+
+Distribution name (can contain % for SQL LIKE query).
 
 =item * B<dist_author> => I<str>
 
-=item * B<module> => I<perl::modname>
+=item * B<module> => I<str>
+
+Module name (can contain % for SQL LIKE query).
 
 =item * B<module_author> => I<str>
 
-=item * B<phase> => I<str> (default: "runtime")
+=item * B<phase> => I<str> (default: "ALL")
 
-=item * B<rel> => I<str> (default: "requires")
+=item * B<rel> => I<str> (default: "ALL")
 
 =back
 
